[ARVADOS] updated: 963f0bf8fc030052aea9a7fcd89ca6ef88967c96

git at public.curoverse.com git at public.curoverse.com
Tue Nov 4 06:33:02 EST 2014


Summary of changes:
 apps/workbench/test/integration/pipeline_instances_test.rb | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

       via  963f0bf8fc030052aea9a7fcd89ca6ef88967c96 (commit)
      from  2a482395964360260020bf70e7645b08b106b1f1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.


commit 963f0bf8fc030052aea9a7fcd89ca6ef88967c96
Author: Phil Hodgson <bitbucket at philhodgson.net>
Date:   Tue Nov 4 12:32:55 2014 +0100

    3618: accommodate new fixture indexing in pipeline_instance tests

diff --git a/apps/workbench/test/integration/pipeline_instances_test.rb b/apps/workbench/test/integration/pipeline_instances_test.rb
index ee4a660..023771a 100644
--- a/apps/workbench/test/integration/pipeline_instances_test.rb
+++ b/apps/workbench/test/integration/pipeline_instances_test.rb
@@ -340,11 +340,11 @@ class PipelineInstancesTest < ActionDispatch::IntegrationTest
   end
 
   [
-    [0, 0], # run time 0 minutes
-    [9, 17*60*60 + 51*60], # run time 17 hours and 51 minutes
+    [1, 1*60*60 + 59*60], # run time 1 hour 59 minutes
+    [10, 19*60*60 + 50*60], # run time 19 hours and 50 minutes
   ].each do |index, run_time|
     test "pipeline start and finish time display #{index}" do
-      visit page_with_token("user1_with_load", "/pipeline_instances/zzzzz-d1hrv-10pipelines0#{index.to_s.rjust(3, '0')}")
+      visit page_with_token("user1_with_load", "/pipeline_instances/zzzzz-d1hrv-10pipelines0#{(index).to_s.rjust(3, '0')}")
 
       assert page.has_text? 'This pipeline started at'
       page_text = page.text

-----------------------------------------------------------------------


hooks/post-receive
-- 




More information about the arvados-commits mailing list